@@ -193,6 +193,9 @@ int language_id(char *text)
       return 1;
   }
 
+  if (text[i-3]=='_' && text[i-2]=='D' && text[i-1]=='A')
+    return 1;
+
   if (text[i-3]=='_' && text[i-2]=='D' && text[i-1]=='E')
     return 1;
 
@@ -214,6 +217,9 @@ int language_id(char *text)
   if (text[i-3]=='_' && text[i-2]=='S' && text[i-1]=='V')
     return 1;
 
+  if (text[i-3]=='_' && text[i-2]=='T' && text[i-1]=='R')
+    return 1;
+
   return 0;
 }
 
@@ -341,7 +347,7 @@ int convert_rc(char *in_filename, char *out_filename)
       case FOUND_DIALOG:
         if (status!=SCANNING)
         {
-          printf(line_buffer);
+          printf("%s", line_buffer);
           wrong_location("DIALOG",infile,outfile,in_filename);
           return 0;
         }
