@@ -85,13 +85,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUB(IDMS_SUPER_SNAPSHOT_4_IMAGE,    NULL, IDM_CART_ATTACH_SS4)
       SUB(IDMS_SUPER_SNAPSHOT_5_IMAGE,    NULL, IDM_CART_ATTACH_SS5)
       SUB(IDMS_STRUCTURED_BASIC_IMAGE,    NULL, IDM_CART_ATTACH_STB)
-/* AmigaOS only support one submenu level */
-    ITEM(IDMS_EXPERT_CART,                NULL, NULL)
-      SUB(IDMS_ENABLE,                    NULL, IDM_CART_ENABLE_EXPERT)
-      SUBSEPARATOR()
-      SUBTOGGLE(IDMS_OFF,                 NULL, IDM_CART_MODE_OFF)
-      SUBTOGGLE(IDMS_PRG,                 NULL, IDM_CART_MODE_PRG)
-      SUBTOGGLE(IDMS_ON,                  NULL, IDM_CART_MODE_ON)
     ITEM(IDMS_SET_CART_AS_DEFAULT,        NULL, IDM_CART_SET_DEFAULT)
     ITEMTOGGLE(IDMS_RESET_ON_CART_CHANGE, NULL, IDM_TOGGLE_CART_RESET)
     ITEMSEPARATOR()
@@ -163,8 +156,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEMTOGGLE(IDMS_VIDEO_CACHE,          NULL, IDM_TOGGLE_VIDEOCACHE)
     ITEMTOGGLE(IDMS_DOUBLE_SIZE,          NULL, IDM_TOGGLE_DOUBLESIZE)
     ITEMTOGGLE(IDMS_DOUBLE_SCAN,          NULL, IDM_TOGGLE_DOUBLESCAN)
-    ITEMTOGGLE(IDMS_PAL_EMULATION,        NULL, IDM_TOGGLE_FASTPAL)
-    ITEMTOGGLE(IDMS_SCALE2X,              NULL, IDM_TOGGLE_SCALE2X)
     ITEM(IDMS_VDC_SETTINGS,               NULL, NULL)
       SUBTOGGLE(IDMS_DOUBLE_SIZE,         NULL, IDM_TOGGLE_VDC_DOUBLESIZE)
       SUBTOGGLE(IDMS_DOUBLE_SCAN,         NULL, IDM_TOGGLE_VDC_DOUBLESCAN)
@@ -193,7 +184,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUBTOGGLE(IDMS_PAL_G,               NULL, IDM_SYNC_FACTOR_PAL)
       SUBTOGGLE(IDMS_NTSC_M,              NULL, IDM_SYNC_FACTOR_NTSC)
     ITEMSEPARATOR()
-    ITEMTOGGLE(IDMS_EMU_ID,               NULL, IDM_TOGGLE_EMUID)
     ITEMTOGGLE(IDMS_IEEE_488_INTERFACE,   NULL, IDM_IEEE488)
     ITEMTOGGLE(IDMS_GRAB_MOUSE,           "Q",  IDM_MOUSE)
 
@@ -202,6 +192,7 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_VIDEO_SETTINGS,             NULL, IDM_VIDEO_SETTINGS)
     ITEM(IDMS_PERIPHERAL_SETTINGS,        NULL, IDM_DEVICEMANAGER)
     ITEM(IDMS_DRIVE_SETTINGS,             NULL, IDM_DRIVE_SETTINGS)
+    ITEM(IDMS_PRINTER_SETTINGS,           NULL, IDM_PRINTER_SETTINGS)
     ITEM(IDMS_DATASETTE_SETTINGS,         NULL, IDM_DATASETTE_SETTINGS)
     ITEM(IDMS_VICII_SETTINGS,             NULL, IDM_VICII_SETTINGS)
 #ifdef AMIGA_OS4
@@ -222,9 +213,11 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_C128_SETTINGS,              NULL, IDM_C128_SETTINGS)
     ITEM(IDMS_CART_IO_SETTINGS,           NULL, NULL)
       SUB(IDMS_REU_SETTINGS,              NULL, IDM_REU_SETTINGS)
+      SUB(IDMS_MAGIC_VOICE_SETTINGS,      NULL, IDM_MAGIC_VOICE_SETTINGS)
       SUB(IDMS_GEORAM_SETTINGS,           NULL, IDM_GEORAM_SETTINGS)
       SUB(IDMS_RAMCART_SETTINGS,          NULL, IDM_RAMCART_SETTINGS)
       SUB(IDMS_DIGIMAX_SETTINGS,          NULL, IDM_DIGIMAX_SETTINGS)
+      SUB(IDMS_EXPERT_SETTINGS,           NULL, IDM_EXPERT_SETTINGS)
       SUB(IDMS_IDE64_SETTINGS,            NULL, IDM_IDE64_SETTINGS)
 #ifdef HAVE_TFE
       SUB(IDMS_ETHERNET_SETTINGS,         NULL, IDM_TFE_SETTINGS)
