@@ -126,8 +126,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEMTOGGLE(IDMS_VIDEO_CACHE,          NULL, IDM_TOGGLE_VIDEOCACHE)
     ITEMTOGGLE(IDMS_DOUBLE_SIZE,          NULL, IDM_TOGGLE_DOUBLESIZE)
     ITEMTOGGLE(IDMS_DOUBLE_SCAN,          NULL, IDM_TOGGLE_DOUBLESCAN)
-    ITEMTOGGLE(IDMS_PAL_EMULATION,        NULL, IDM_TOGGLE_FASTPAL)
-    ITEMTOGGLE(IDMS_SCALE2X,              NULL, IDM_TOGGLE_SCALE2X)
 #if defined(HAVE_PROTO_CYBERGRAPHICS_H) && defined(HAVE_XVIDEO)
     ITEMTOGGLE(IDMS_VIDEO_OVERLAY,        NULL, IDM_TOGGLE_OVERLAY)
 #endif
@@ -154,6 +152,7 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_VIDEO_SETTINGS,             NULL, IDM_VIDEO_SETTINGS)
     ITEM(IDMS_PERIPHERAL_SETTINGS,        NULL, IDM_DEVICEMANAGER)
     ITEM(IDMS_DRIVE_SETTINGS,             NULL, IDM_DRIVE_SETTINGS)
+    ITEM(IDMS_PRINTER_SETTINGS,           NULL, IDM_PRINTER_SETTINGS)
     ITEM(IDMS_VICII_SETTINGS,             NULL, IDM_VICII_SETTINGS)
 #ifdef AMIGA_OS4
     ITEM(IDMS_JOYSTICK_SETTINGS,          NULL, IDM_JOY_SETTINGS)
