@@ -31,23 +31,30 @@
 #define UI_TRANSLATED_MENU_NAME c64_ui_menu
 
 #include "private.h"
+#include "c64model.h"
 #include "c64ui.h"
 #include "c64uires.h"
+#include "translate.h"
 #include "uic64cart.h"
 
 #include "mui/uiacia.h"
 #include "mui/uic64_256k.h"
+#include "mui/uic64model.h"
 #include "mui/uidigimax.h"
 #include "mui/uidrivec64vic20.h"
 #include "mui/uieasyflash.h"
+#include "mui/uiexpert.h"
 #include "mui/uigeoram.h"
 #include "mui/uiide64.h"
 #include "mui/uijoystick.h"
 #include "mui/uijoystickll.h"
+#include "mui/uimagicvoice.h"
 #include "mui/uimmc64.h"
+#include "mui/uimmcreplay.h"
 #include "mui/uimouse.h"
 #include "mui/uiplus256k.h"
 #include "mui/uiplus60k.h"
+#include "mui/uiprinter.h"
 #include "mui/uiramcart.h"
 #include "mui/uireu.h"
 #include "mui/uiromc64vic20settings.h"
@@ -55,17 +62,14 @@
 #include "mui/uisid.h"
 #include "mui/uisoundexpander.h"
 #include "mui/uivicii.h"
-#include "mui/uivideoc64plus4vic20.h"
+#include "mui/uivideo.h"
 
 static const ui_menu_toggle_t c64_ui_menu_toggles[] = {
     { "VICIIDoubleSize", IDM_TOGGLE_DOUBLESIZE },
     { "VICIIDoubleScan", IDM_TOGGLE_DOUBLESCAN },
-    { "VICIIScale2x", IDM_TOGGLE_SCALE2X },
-    { "PALEmulation", IDM_TOGGLE_FASTPAL },
     { "VICIIVideoCache", IDM_TOGGLE_VIDEOCACHE },
     { "Mouse", IDM_MOUSE },
     { "CartridgeReset", IDM_TOGGLE_CART_RESET },
-    { "EmuID", IDM_TOGGLE_EMUID },
     { "SFXSoundSampler", IDM_TOGGLE_SFX_SS },
     { NULL, 0 }
 };
@@ -75,6 +79,30 @@ static int c64_ui_specific(video_canvas_t *canvas, int idm)
     uic64cart_proc(canvas, idm);
 
     switch (idm) {
+        case IDM_C64_MODEL_C64_PAL:
+            c64model_set(C64MODEL_C64_PAL);
+            break;
+        case IDM_C64_MODEL_C64C_PAL:
+            c64model_set(C64MODEL_C64C_PAL);
+            break;
+        case IDM_C64_MODEL_C64_OLD_PAL:
+            c64model_set(C64MODEL_C64_OLD_PAL);
+            break;
+        case IDM_C64_MODEL_C64_NTSC:
+            c64model_set(C64MODEL_C64_NTSC);
+            break;
+        case IDM_C64_MODEL_C64C_NTSC:
+            c64model_set(C64MODEL_C64C_NTSC);
+            break;
+        case IDM_C64_MODEL_C64_OLD_NTSC:
+            c64model_set(C64MODEL_C64_OLD_NTSC);
+            break;
+        case IDM_C64_MODEL_DREAN:
+            c64model_set(C64MODEL_C64_PAL_N);
+            break;
+        case IDM_C64_MODEL_CUSTOM:
+            ui_c64_model_custom_dialog();
+            break;
         case IDM_VICII_SETTINGS:
             ui_vicii_settings_dialog();
             break;
@@ -84,6 +112,9 @@ static int c64_ui_specific(video_canvas_t *canvas, int idm)
         case IDM_REU_SETTINGS:
             ui_reu_settings_dialog(canvas);
             break;
+        case IDM_MAGIC_VOICE_SETTINGS:
+            ui_magicvoice_settings_dialog(canvas);
+            break;
         case IDM_GEORAM_SETTINGS:
             ui_georam_settings_dialog(canvas);
             break;
@@ -96,6 +127,9 @@ static int c64_ui_specific(video_canvas_t *canvas, int idm)
         case IDM_ISEPIC_SETTINGS:
             ui_isepic_settings_dialog(canvas);
             break;
+        case IDM_EXPERT_SETTINGS:
+            ui_expert_settings_dialog(canvas);
+            break;
         case IDM_PLUS60K_SETTINGS:
             ui_plus60k_settings_dialog(canvas);
             break;
@@ -108,6 +142,9 @@ static int c64_ui_specific(video_canvas_t *canvas, int idm)
         case IDM_MMC64_SETTINGS:
             ui_mmc64_settings_dialog(canvas);
             break;
+        case IDM_MMCREPLAY_SETTINGS:
+            ui_mmcreplay_settings_dialog(canvas);
+            break;
         case IDM_DIGIMAX_SETTINGS:
             ui_digimax_settings_dialog(canvas);
             break;
@@ -132,11 +169,19 @@ static int c64_ui_specific(video_canvas_t *canvas, int idm)
             break;
 #endif
         case IDM_VIDEO_SETTINGS:
-            ui_video_c64plus4vic20_settings_dialog(canvas, "VICIIExternalPalette", "VICIIPaletteFile");
+            ui_video_settings_dialog(canvas,
+                                     "VICIIExternalPalette", "VICIIPaletteFile",
+                                     translate_text(IDS_VICII_EXTERNAL_PALETTE), translate_text(IDS_VICII_PALETTE_NAME),
+                                     NULL, NULL,
+                                     NULL, NULL,
+                                     "VICIIScale2x");
             break;
         case IDM_DRIVE_SETTINGS:
             uidrivec64vic20_settings_dialog();
             break;
+        case IDM_PRINTER_SETTINGS:
+            ui_printer_settings_dialog(canvas, 0, 1);
+            break;
         case IDM_ACIA_SETTINGS:
             ui_acia64128_settings_dialog();
             break;
@@ -178,6 +223,18 @@ int c64ui_init(void)
     return 0;
 }
 
+int c64scui_init(void)
+{
+    uic64cart_init();
+
+    ui_register_menu_translation_layout(c64_ui_translation_menu);
+    ui_register_menu_layout(c64_ui_menu);
+    ui_register_machine_specific(c64_ui_specific);
+    ui_register_menu_toggles(c64_ui_menu_toggles);
+
+    return 0;
+}
+
 void c64ui_shutdown(void)
 {
 }
