@@ -85,13 +85,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUB(IDMS_SUPER_SNAPSHOT_4_IMAGE,    NULL, IDM_CART_ATTACH_SS4)
       SUB(IDMS_SUPER_SNAPSHOT_5_IMAGE,    NULL, IDM_CART_ATTACH_SS5)
       SUB(IDMS_STRUCTURED_BASIC_IMAGE,    NULL, IDM_CART_ATTACH_STB)
-/* AmigaOS only support one submenu level */
-    ITEM(IDMS_EXPERT_CART,                NULL, NULL)
-      SUB(IDMS_ENABLE,                    NULL, IDM_CART_ENABLE_EXPERT)
-      SUBSEPARATOR()
-      SUBTOGGLE(IDMS_OFF,                 NULL, IDM_CART_MODE_OFF)
-      SUBTOGGLE(IDMS_PRG,                 NULL, IDM_CART_MODE_PRG)
-      SUBTOGGLE(IDMS_ON,                  NULL, IDM_CART_MODE_ON)
     ITEM(IDMS_SET_CART_AS_DEFAULT,        NULL, IDM_CART_SET_DEFAULT)
     ITEMTOGGLE(IDMS_RESET_ON_CART_CHANGE, NULL, IDM_TOGGLE_CART_RESET)
     ITEMSEPARATOR()
@@ -167,8 +160,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEMTOGGLE(IDMS_VIDEO_CACHE,          NULL, IDM_TOGGLE_VIDEOCACHE)
     ITEMTOGGLE(IDMS_DOUBLE_SIZE,          NULL, IDM_TOGGLE_DOUBLESIZE)
     ITEMTOGGLE(IDMS_DOUBLE_SCAN,          NULL, IDM_TOGGLE_DOUBLESCAN)
-    ITEMTOGGLE(IDMS_PAL_EMULATION,        NULL, IDM_TOGGLE_FASTPAL)
-    ITEMTOGGLE(IDMS_SCALE2X,              NULL, IDM_TOGGLE_SCALE2X)
 #if defined(HAVE_PROTO_CYBERGRAPHICS_H) && defined(HAVE_XVIDEO)
     ITEMTOGGLE(IDMS_VIDEO_OVERLAY,        NULL, IDM_TOGGLE_OVERLAY)
 #endif
@@ -189,14 +180,23 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUBTOGGLE(IDMS_NTSC_M,              NULL, IDM_SYNC_FACTOR_NTSC)
       SUBTOGGLE(IDMS_OLD_NTSC_M,          NULL, IDM_SYNC_FACTOR_NTSCOLD)
     ITEMSEPARATOR()
-    ITEMTOGGLE(IDMS_EMU_ID,               NULL, IDM_TOGGLE_EMUID)
     ITEMTOGGLE(IDMS_GRAB_MOUSE,           "Q",  IDM_MOUSE)
 
   TITLE(IDMS_SETTINGS, NULL)
+    ITEM(IDMS_C64_MODEL_SETTINGS,         NULL, NULL)
+      SUB(IDMS_C64_PAL,                   NULL, IDM_C64_MODEL_C64_PAL)
+      SUB(IDMS_C64C_PAL,                  NULL, IDM_C64_MODEL_C64C_PAL)
+      SUB(IDMS_C64_OLD_PAL,               NULL, IDM_C64_MODEL_C64_OLD_PAL)
+      SUB(IDMS_C64_NTSC,                  NULL, IDM_C64_MODEL_C64_NTSC)
+      SUB(IDMS_C64C_NTSC,                 NULL, IDM_C64_MODEL_C64C_NTSC)
+      SUB(IDMS_C64_OLD_NTSC,              NULL, IDM_C64_MODEL_C64_OLD_NTSC)
+      SUB(IDMS_DREAN,                     NULL, IDM_C64_MODEL_DREAN)
+      SUB(IDMS_CUSTOM_C64_MODEL,          NULL, IDM_C64_MODEL_CUSTOM)
     ITEM(IDMS_AUTOSTART_SETTINGS,         NULL, IDM_AUTOSTART_SETTINGS)
     ITEM(IDMS_VIDEO_SETTINGS,             NULL, IDM_VIDEO_SETTINGS)
     ITEM(IDMS_PERIPHERAL_SETTINGS,        NULL, IDM_DEVICEMANAGER)
     ITEM(IDMS_DRIVE_SETTINGS,             NULL, IDM_DRIVE_SETTINGS)
+    ITEM(IDMS_PRINTER_SETTINGS,           NULL, IDM_PRINTER_SETTINGS)
     ITEM(IDMS_DATASETTE_SETTINGS,         NULL, IDM_DATASETTE_SETTINGS)
     ITEM(IDMS_VICII_SETTINGS,             NULL, IDM_VICII_SETTINGS)
 #ifdef AMIGA_OS4
@@ -216,15 +216,18 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_RS232_SETTINGS,             NULL, IDM_RS232_SETTINGS)
     ITEM(IDMS_CART_IO_SETTINGS,           NULL, NULL)
       SUB(IDMS_REU_SETTINGS,              NULL, IDM_REU_SETTINGS)
+      SUB(IDMS_MAGIC_VOICE_SETTINGS,      NULL, IDM_MAGIC_VOICE_SETTINGS)
       SUB(IDMS_GEORAM_SETTINGS,           NULL, IDM_GEORAM_SETTINGS)
       SUB(IDMS_RAMCART_SETTINGS,          NULL, IDM_RAMCART_SETTINGS)
       SUB(IDMS_DQBB_SETTINGS,             NULL, IDM_DQBB_SETTINGS)
       SUB(IDMS_ISEPIC_SETTINGS,           NULL, IDM_ISEPIC_SETTINGS)
       SUB(IDMS_DIGIMAX_SETTINGS,          NULL, IDM_DIGIMAX_SETTINGS)
+      SUB(IDMS_EXPERT_SETTINGS,           NULL, IDM_EXPERT_SETTINGS)
       SUB(IDMS_PLUS60K_SETTINGS,          NULL, IDM_PLUS60K_SETTINGS)
       SUB(IDMS_PLUS256K_SETTINGS,         NULL, IDM_PLUS256K_SETTINGS)
       SUB(IDMS_256K_SETTINGS,             NULL, IDM_C64_256K_SETTINGS)
       SUB(IDMS_MMC64_SETTINGS,            NULL, IDM_MMC64_SETTINGS)
+      SUB(IDMS_MMCREPLAY_SETTINGS,        NULL, IDM_MMCREPLAY_SETTINGS)
       SUB(IDMS_IDE64_SETTINGS,            NULL, IDM_IDE64_SETTINGS)
 #ifdef HAVE_TFE
       SUB(IDMS_ETHERNET_SETTINGS,         NULL, IDM_TFE_SETTINGS)
