@@ -153,8 +153,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_DRIVE_SYNC_FACTOR,          NULL, NULL)
       SUBTOGGLE(IDMS_PAL,                 NULL, IDM_SYNC_FACTOR_PAL)
       SUBTOGGLE(IDMS_NTSC,                NULL, IDM_SYNC_FACTOR_NTSC)
-    ITEMSEPARATOR()
-    ITEMTOGGLE(IDMS_EMU_ID,               NULL, IDM_TOGGLE_EMUID)
 
   TITLE(IDMS_SETTINGS, NULL)
     ITEM(IDMS_AUTOSTART_SETTINGS,         NULL, IDM_AUTOSTART_SETTINGS)
@@ -162,6 +160,7 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_CBM2_SETTINGS,              NULL, IDM_CBM2_SETTINGS)
     ITEM(IDMS_PERIPHERAL_SETTINGS,        NULL, IDM_DEVICEMANAGER)
     ITEM(IDMS_DRIVE_SETTINGS,             NULL, IDM_DRIVE_SETTINGS)
+    ITEM(IDMS_PRINTER_SETTINGS,           NULL, IDM_PRINTER_SETTINGS)
     ITEM(IDMS_DATASETTE_SETTINGS,         NULL, IDM_DATASETTE_SETTINGS)
     ITEM(IDMS_VICII_SETTINGS,             NULL, IDM_VICII_SETTINGS)
 #ifdef AMIGA_OS4
