@@ -36,6 +36,7 @@
 
 #include "mui.h"
 #include "private.h"
+#include "platform.h"
 #include "intl.h"
 #include "translate.h"
 
@@ -101,6 +102,20 @@ static void cycle_get_to_ui(ui_to_from_t *data)
     }
 }
 
+static void cycle_string_get_to_ui(ui_to_from_t *data)
+{
+    int n;
+    char *str1, str2;
+
+    resources_get_value(data->resource, (void *)&str1);
+    for (n = 0; data->string_choices[n] != NULL; n++) {
+        if (!strcmp(data->string_choices[n], str1)) {
+            set(data->object, MUIA_Cycle_Active, n);
+            break;
+        }
+    }
+}
+
 static void cycle_sid_get_to_ui(ui_to_from_t *data)
 {
     int n, temp = 0, val = 0;
@@ -126,6 +141,16 @@ static void cycle_get_from_ui(ui_to_from_t *data)
     resources_set_value(data->resource, (resource_value_t *)val);
 }
 
+static void cycle_string_get_from_ui(ui_to_from_t *data)
+{
+    int n;
+    char *str;
+
+    get(data->object, MUIA_Cycle_Active, (APTR)&n);
+    str = data->string_choices[n];
+    resources_set_value(data->resource, (resource_value_t *)str);
+}
+
 static void cycle_sid_get_from_ui(ui_to_from_t *data)
 {
     int n, val = 0;
@@ -156,6 +181,16 @@ static void integer_get_from_ui(ui_to_from_t *data)
 
     get(data->object, MUIA_String_Contents, (APTR)&str);
     val = atoi(str);
+    if (data->values != NULL) {
+        if (val < data->values[0]) {
+            ui_error(translate_text(IDMES_VALUE_D_OUT_OF_RANGE_USING_D_INSTEAD), val, data->values[0], data->values[1], data->values[0]);
+            val = data->values[0];
+        }
+        if (val > data->values[1]) {
+            ui_error(translate_text(IDMES_VALUE_D_OUT_OF_RANGE_USING_D_INSTEAD), val, data->values[0], data->values[1], data->values[1]);
+            val = data->values[1];
+        }
+    }
     resources_set_value(data->resource, (resource_value_t *)val);
 }
 
@@ -212,6 +247,16 @@ static void float_get_from_ui(ui_to_from_t *data)
     get(data->object, MUIA_String_Contents, (APTR)&str);
     fval = atof(str);
     val = (int)(fval * 1000.0 + 0.5);
+    if (data->values != NULL) {
+        if (val < data->values[0]) {
+            ui_error(translate_text(IDMES_VALUE_F_OUT_OF_RANGE_USING_F_INSTEAD), fval, (float)(data->values[0] / 1000), (float)(data->values[1] / 1000), (float)(data->values[0] / 1000));
+            val = data->values[0];
+        }
+        if (val > data->values[1]) {
+            ui_error(translate_text(IDMES_VALUE_F_OUT_OF_RANGE_USING_F_INSTEAD), val, (float)(data->values[0] / 1000), (float)(data->values[1] / 1000), (float)(data->values[1] / 1000));
+            val = data->values[1];
+        }
+    }
     resources_set_value(data->resource, (resource_value_t *)val);
 }
 
@@ -232,6 +277,9 @@ void ui_get_from(ui_to_from_t *data)
                 case MUI_TYPE_CYCLE:
                     cycle_get_from_ui(data);
                     break;
+                case MUI_TYPE_CYCLE_STR:
+                    cycle_string_get_from_ui(data);
+                    break;
                 case MUI_TYPE_CYCLE_SID:
                     cycle_sid_get_from_ui(data);
                     break;
@@ -272,6 +320,9 @@ void ui_get_to(ui_to_from_t *data)
                 case MUI_TYPE_CYCLE:
                     cycle_get_to_ui(data);
                     break;
+                case MUI_TYPE_CYCLE_STR:
+                    cycle_string_get_to_ui(data);
+                    break;
                 case MUI_TYPE_CYCLE_SID:
                     cycle_sid_get_to_ui(data);
                     break;
@@ -345,29 +396,25 @@ void ui_about(void)
         "",
         "Versatile Commodore Emulator",
         "",
-        "Version " VERSION,
+        "Version " VERSION " (" PLATFORM_CPU " " PLATFORM_OS " " PLATFORM_COMPILER ")",
         "",
         "The VICE Team",
-        "Copyright @ 1998-2009 Andreas Boose",
-        "Copyright @ 1998-2009 Dag Lem",
-        "Copyright @ 1998-2009 Tibor Biczo",
-        "Copyright @ 1999-2009 Andreas Dehmel",
-        "Copyright @ 1999-2009 Martin Pottendorfer",
-        "Copyright @ 1999-2009 Andreas Matthies",
-        "Copyright @ 2000-2009 Spiro Trikaliotis",
-        "Copyright @ 2005-2009 Marco van den Heuvel",
-        "Copyright @ 2006-2009 Christian Vogelgsang",
-        "Copyright @ 2007-2009 Fabrizio Gennari",
-        "Copyright @ 2007-2009 M. Kiesel",
-        "Copyright @ 2007-2009 Hannu Nuotio",
-        "Copyright @ 2007-2009 Daniel Kahlin",
-        "Copyright @ 2008-2009 Antti S. Lankila",
-        "Copyright @ 2003-2005 David Hansel",
-        "Copyright @ 1999-2004 Thomas Bretz",
-        "Copyright @ 2000-2004 Markus Brenner",
+        "Copyright \xa9 1998-2011 Dag Lem",
+        "Copyright \xa9 1999-2011 Andreas Matthies",
+        "Copyright \xa9 1999-2011 Martin Pottendorfer",
+        "Copyright \xa9 2000-2011 Spiro Trikaliotis",
+        "Copyright \xa9 2005-2011 Marco van den Heuvel",
+        "Copyright \xa9 2006-2011 Christian Vogelgsang",
+        "Copyright \xa9 2007-2011 Fabrizio Gennari",
+        "Copyright \xa9 2007-2011 Daniel Kahlin",
+        "Copyright \xa9 2008-2011 Antti S. Lankila",
+        "Copyright \xa9 2009-2011 Groepaz",
+        "Copyright \xa9 2009-2011 Ingo Korb",
+        "Copyright \xa9 2009-2011 Errol Smith",
+        "Copyright \xa9 2009-2011 Olaf Seibert",
         "",
         "Official VICE homepage:",
-        "http://www.viceteam.org/",
+        "http://vice-emu.sourceforge.net/",
         NULL};
 
     while (authors[i] != NULL) {
@@ -394,7 +441,7 @@ int mui_init(void)
             MUIA_Application_Title, "VICE",
             MUIA_Application_Version, "$VER: VICE " VERSION,
             MUIA_Application_Copyright, "The VICE Team",
-            MUIA_Application_Description, "VICE",
+            MUIA_Application_Description, "Versatile Commodore Emulator",
           End;
 
     return ((app == NULL) ? -1 : 0);
@@ -548,6 +595,7 @@ char *BrowseFile(char *select_text, char *pattern, video_canvas_t *canvas)
                                 ASLFR_InitialPattern, pattern,
                                 ASLFR_PositiveText, select_text,
                                 (struct TagItem *)TAG_DONE)) {
+        fname[0]=0;
         strcat(fname,request->rf_Dir);
         if (fname[strlen(fname) - 1] != (UBYTE)58) {
             strcat(fname, "/");
