@@ -116,17 +116,22 @@ static char *ui_sound_formats[] = {
     NULL
 };
 
+static const int ui_volume_range[] = {
+    0,
+    100
+};
+
 static ui_to_from_t ui_to_from[] = {
-    { NULL, MUI_TYPE_CYCLE, "SoundSampleRate", ui_sound_freq, ui_sound_freq_values },
-    { NULL, MUI_TYPE_CYCLE, "SoundBufferSize", ui_sound_buffer, ui_sound_buffer_values },
-    { NULL, MUI_TYPE_CYCLE, "SoundFragmentSize", ui_sound_fragment_size, ui_sound_fragment_size_values },
-    { NULL, MUI_TYPE_CYCLE, "SoundSpeedAdjustment", ui_sound_adjusting, ui_sound_adjusting_values },
-    { NULL, MUI_TYPE_INTEGER, "SoundVolume", NULL, NULL },
+    { NULL, MUI_TYPE_CYCLE, "SoundSampleRate", ui_sound_freq, ui_sound_freq_values, NULL },
+    { NULL, MUI_TYPE_CYCLE, "SoundBufferSize", ui_sound_buffer, ui_sound_buffer_values, NULL },
+    { NULL, MUI_TYPE_CYCLE, "SoundFragmentSize", ui_sound_fragment_size, ui_sound_fragment_size_values, NULL },
+    { NULL, MUI_TYPE_CYCLE, "SoundSpeedAdjustment", ui_sound_adjusting, ui_sound_adjusting_values, NULL },
+    { NULL, MUI_TYPE_INTEGER, "SoundVolume", NULL, ui_volume_range, NULL },
     UI_END /* mandatory */
 };
 
 static ui_to_from_t ui_to_from_record[] = {
-    { NULL, MUI_TYPE_FILENAME, "SoundRecordDeviceArg", NULL, NULL },
+    { NULL, MUI_TYPE_FILENAME, "SoundRecordDeviceArg", NULL, NULL, NULL },
     UI_END /* mandatory */
 };
 
@@ -191,6 +196,7 @@ static APTR build_gui_record(void)
 void ui_sound_settings_dialog(void)
 {
     intl_convert_mui_table(ui_sound_adjusting_translate, ui_sound_adjusting);
+    intl_convert_mui_table(ui_sound_fragment_size_translate, ui_sound_fragment_size);
     mui_show_dialog(build_gui(), translate_text(IDS_SOUND_SETTINGS), ui_to_from);
 }
 
