@@ -49,11 +49,11 @@ static const int ui_vic20mem_enable_values[] = {
 };
 
 static ui_to_from_t ui_to_from[] = {
-    { NULL, MUI_TYPE_CYCLE, "RAMBlock0", ui_vic20mem_enable, ui_vic20mem_enable_values },
-    { NULL, MUI_TYPE_CYCLE, "RAMBlock1", ui_vic20mem_enable, ui_vic20mem_enable_values },
-    { NULL, MUI_TYPE_CYCLE, "RAMBlock2", ui_vic20mem_enable, ui_vic20mem_enable_values },
-    { NULL, MUI_TYPE_CYCLE, "RAMBlock3", ui_vic20mem_enable, ui_vic20mem_enable_values },
-    { NULL, MUI_TYPE_CYCLE, "RAMBlock5", ui_vic20mem_enable, ui_vic20mem_enable_values },
+    { NULL, MUI_TYPE_CYCLE, "RAMBlock0", ui_vic20mem_enable, ui_vic20mem_enable_values, NULL },
+    { NULL, MUI_TYPE_CYCLE, "RAMBlock1", ui_vic20mem_enable, ui_vic20mem_enable_values, NULL },
+    { NULL, MUI_TYPE_CYCLE, "RAMBlock2", ui_vic20mem_enable, ui_vic20mem_enable_values, NULL },
+    { NULL, MUI_TYPE_CYCLE, "RAMBlock3", ui_vic20mem_enable, ui_vic20mem_enable_values, NULL },
+    { NULL, MUI_TYPE_CYCLE, "RAMBlock5", ui_vic20mem_enable, ui_vic20mem_enable_values, NULL },
     UI_END /* mandatory */
 };
 
