@@ -152,8 +152,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_DRIVE_SYNC_FACTOR,          NULL, NULL)
       SUBTOGGLE(IDMS_PAL,                 NULL, IDM_SYNC_FACTOR_PAL)
       SUBTOGGLE(IDMS_NTSC,                NULL, IDM_SYNC_FACTOR_NTSC)
-    ITEMSEPARATOR()
-    ITEMTOGGLE(IDMS_EMU_ID,               NULL, IDM_TOGGLE_EMUID)
 
   TITLE(IDMS_SETTINGS, NULL)
     ITEM(IDMS_AUTOSTART_SETTINGS,         NULL, IDM_AUTOSTART_SETTINGS)
@@ -162,6 +160,7 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_PET_SETTINGS,               NULL, IDM_PET_SETTINGS)
     ITEM(IDMS_PERIPHERAL_SETTINGS,        NULL, IDM_DEVICEMANAGER)
     ITEM(IDMS_DRIVE_SETTINGS,             NULL, IDM_DRIVE_SETTINGS)
+    ITEM(IDMS_PRINTER_SETTINGS,           NULL, IDM_PRINTER_SETTINGS)
     ITEM(IDMS_DATASETTE_SETTINGS,         NULL, IDM_DATASETTE_SETTINGS)
 #ifdef AMIGA_OS4
     ITEM(IDMS_JOYSTICK_SETTINGS,          NULL, IDM_JOY_SETTINGS)
@@ -180,6 +179,8 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUB(IDMS_ACIA_SETTINGS,             NULL, IDM_ACIA_SETTINGS)
       SUB(IDMS_PETREU_SETTINGS,           NULL, IDM_PETREU_SETTINGS)
       SUB(IDMS_SIDCART_SETTINGS,          NULL, IDM_SIDCART_SETTINGS)
+      SUB(IDMS_PETDWW_SETTINGS,           NULL, IDM_PETDWW_SETTINGS)
+      SUB(IDMS_ENABLE_USERPORT_DAC,       NULL, IDM_TOGGLE_USERPORT_DAC)
     ITEMSEPARATOR()
     ITEM(IDMS_SAVE_CURRENT_SETTINGS_FILE, NULL, IDM_SETTINGS_SAVE_FILE)
     ITEM(IDMS_LOAD_SAVED_SETTINGS_FILE,   NULL, IDM_SETTINGS_LOAD_FILE)
