@@ -146,8 +146,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEMTOGGLE(IDMS_VIDEO_CACHE,          NULL, IDM_TOGGLE_VIDEOCACHE)
     ITEMTOGGLE(IDMS_DOUBLE_SIZE,          NULL, IDM_TOGGLE_DOUBLESIZE)
     ITEMTOGGLE(IDMS_DOUBLE_SCAN,          NULL, IDM_TOGGLE_DOUBLESCAN)
-    ITEMTOGGLE(IDMS_PAL_EMULATION,        NULL, IDM_TOGGLE_FASTPAL)
-    ITEMTOGGLE(IDMS_SCALE2X,              NULL, IDM_TOGGLE_SCALE2X)
 #if defined(HAVE_PROTO_CYBERGRAPHICS_H) && defined(HAVE_XVIDEO)
     ITEMTOGGLE(IDMS_VIDEO_OVERLAY,        NULL, IDM_TOGGLE_OVERLAY)
 #endif
@@ -171,6 +169,7 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_VIDEO_SETTINGS,             NULL, IDM_VIDEO_SETTINGS)
     ITEM(IDMS_PERIPHERAL_SETTINGS,        NULL, IDM_DEVICEMANAGER)
     ITEM(IDMS_DRIVE_SETTINGS,             NULL, IDM_DRIVE_SETTINGS)
+    ITEM(IDMS_PRINTER_SETTINGS,           NULL, IDM_PRINTER_SETTINGS)
     ITEM(IDMS_DATASETTE_SETTINGS,         NULL, IDM_DATASETTE_SETTINGS)
     ITEM(IDMS_PLUS4_SETTINGS,             NULL, IDM_PLUS4_SETTINGS)
 #ifdef AMIGA_OS4
@@ -189,6 +188,7 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_CART_IO_SETTINGS,           NULL, NULL)
       SUB(IDMS_ACIA_SETTINGS,             NULL, IDM_ACIA_SETTINGS)
       SUB(IDMS_SIDCART_SETTINGS,          NULL, IDM_SIDCART_SETTINGS)
+      SUB(IDMS_V364_SPEECH_SETTINGS,      NULL, IDM_V364_SPEECH_SETTINGS)
     ITEMSEPARATOR()
     ITEM(IDMS_SAVE_CURRENT_SETTINGS_FILE, NULL, IDM_SETTINGS_SAVE_FILE)
     ITEM(IDMS_LOAD_SAVED_SETTINGS_FILE,   NULL, IDM_SETTINGS_LOAD_FILE)
