@@ -24,14 +24,12 @@
  *
  */
 
-#ifndef _TIMER_H_
-#define _TIMER_H_
+#ifndef VICE_TIMER_H_
+#define VICE_TIMER_H_
 
 #include "vice.h"
 
-#ifndef __VBCC__
 #include <proto/timer.h>
-#endif
 
 #ifdef AMIGA_AROS
 #include <aros/_timeval.h>
@@ -47,7 +45,9 @@ extern void timer_usleep(void *timer, int us);
 
 #else
 
+#ifndef __timer_t_defined
 typedef struct timer_s timer_t;
+#endif
 
 extern timer_t *timer_init(void);
 extern void timer_gettime(timer_t *timer, struct timeval *tv);
