@@ -72,6 +72,7 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUB(IDMS_GENERIC_IMAGE,         NULL, IDM_CART_VIC20_GENERIC)
       SUB(IDMS_MEGA_CART_IMAGE,       NULL, IDM_CART_VIC20_MEGACART)
       SUB(IDMS_FINAL_EXPANSION_IMAGE, NULL, IDM_CART_VIC20_FINAL_EXPANSION)
+      SUB(IDMS_FP_IMAGE,              NULL, IDM_CART_VIC20_FP)
       ITEMSEPARATOR()
       ITEM(IDMS_ADD_TO_GENERIC,       NULL, NULL)
         SUB(IDMS_SMART_ATTACH_IMAGE,  NULL, IDM_CART_VIC20_SMART_ATTACH)
@@ -154,8 +155,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEMTOGGLE(IDMS_VIDEO_CACHE,          NULL, IDM_TOGGLE_VIDEOCACHE)
     ITEMTOGGLE(IDMS_DOUBLE_SIZE,          NULL, IDM_TOGGLE_DOUBLESIZE)
     ITEMTOGGLE(IDMS_DOUBLE_SCAN,          NULL, IDM_TOGGLE_DOUBLESCAN)
-    ITEMTOGGLE(IDMS_PAL_EMULATION,        NULL, IDM_TOGGLE_FASTPAL)
-    ITEMTOGGLE(IDMS_SCALE2X,              NULL, IDM_TOGGLE_SCALE2X)
 #if defined(HAVE_PROTO_CYBERGRAPHICS_H) && defined(HAVE_XVIDEO)
     ITEMTOGGLE(IDMS_VIDEO_OVERLAY,        NULL, IDM_TOGGLE_OVERLAY)
 #endif
@@ -174,7 +173,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUBTOGGLE(IDMS_PAL_G,               NULL, IDM_SYNC_FACTOR_PAL)
       SUBTOGGLE(IDMS_NTSC_M,              NULL, IDM_SYNC_FACTOR_NTSC)
     ITEMSEPARATOR()
-    ITEMTOGGLE(IDMS_EMU_ID,               NULL, IDM_TOGGLE_EMUID)
     ITEMTOGGLE(IDMS_VIC_1112_IEEE_488,    NULL, IDM_IEEE488)
     ITEMTOGGLE(IDMS_ENABLE_PADDLES,       "Q",  IDM_MOUSE)
 
@@ -184,6 +182,7 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_VIC_SETTINGS,               NULL, IDM_VIC_SETTINGS)
     ITEM(IDMS_PERIPHERAL_SETTINGS,        NULL, IDM_DEVICEMANAGER)
     ITEM(IDMS_DRIVE_SETTINGS,             NULL, IDM_DRIVE_SETTINGS)
+    ITEM(IDMS_PRINTER_SETTINGS,           NULL, IDM_PRINTER_SETTINGS)
     ITEM(IDMS_DATASETTE_SETTINGS,         NULL, IDM_DATASETTE_SETTINGS)
 #ifdef AMIGA_OS4
     ITEM(IDMS_JOYSTICK_SETTINGS,          NULL, IDM_JOY_SETTINGS)
@@ -202,6 +201,7 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUB(IDMS_RS232_USERPORT_SETTINGS,   NULL, IDM_RS232USER_SETTINGS)
       SUB(IDMS_SIDCART_SETTINGS,          NULL, IDM_SIDCART_SETTINGS)
       SUB(IDMS_FINAL_EXPANSION_WRITEBACK, NULL, IDM_FINAL_EXPANSION_WRITEBACK)
+      SUB(IDMS_FP_WRITEBACK,              NULL, IDM_FP_WRITEBACK)
       SUB(IDMS_MEGACART_WRITEBACK,        NULL, IDM_MEGACART_WRITEBACK)
       SUB(IDMS_MEGACART_WRITEBACK_FILE,   NULL, IDM_MEGACART_WRITEBACK_FILE)
     ITEMSEPARATOR()
