@@ -24,21 +24,21 @@
  *
  */
 
-#ifndef _ARCHDEP_H
-#define _ARCHDEP_H
+#ifndef VICE_ARCHDEP_H
+#define VICE_ARCHDEP_H
 
 #include "archapi.h"
 
 /* Filesystem dependant operators.  */
-#define FSDEVICE_DEFAULT_DIR   "."
-#define FSDEV_DIR_SEP_STR      "/"
-#define FSDEV_DIR_SEP_CHR      '/'
-#define FSDEV_EXT_SEP_STR      "."
-#define FSDEV_EXT_SEP_CHR      '.'
+#define FSDEVICE_DEFAULT_DIR "."
+#define FSDEV_DIR_SEP_STR    "/"
+#define FSDEV_DIR_SEP_CHR    '/'
+#define FSDEV_EXT_SEP_STR    "."
+#define FSDEV_EXT_SEP_CHR    '.'
 
 /* Path separator.  */
-#define ARCHDEP_FINDPATH_SEPARATOR_CHAR         ';'
-#define ARCHDEP_FINDPATH_SEPARATOR_STRING       ";"
+#define ARCHDEP_FINDPATH_SEPARATOR_CHAR   ';'
+#define ARCHDEP_FINDPATH_SEPARATOR_STRING ";"
 
 /* Modes for fopen().  */
 #define MODE_READ              "rb"
@@ -46,7 +46,7 @@
 #define MODE_READ_WRITE        "r+b"
 #define MODE_WRITE             "wb"
 #define MODE_WRITE_TEXT        "wt"
-#define MODE_APPEND            "wb"
+#define MODE_APPEND            "ab"
 #define MODE_APPEND_READ_WRITE "a+b"
 
 /* Printer default devices.  */
@@ -93,8 +93,10 @@
 /* Ethernet default device */
 #define ARCHDEP_ETHERNET_DEFAULT_DEVICE ""
 
+/* Default sound fragment size */
+#define ARCHDEP_SOUND_FRAGMENT_SIZE 1
+
 /* No key symcode.  */
 #define ARCHDEP_KEYBOARD_SYM_NONE 0
 
 #endif
-
